@@ -25,6 +25,8 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/button.h>
 
+namespace Glom
+{
 
 class Dialog_Glom :
   public Gtk::Dialog
@@ -42,4 +44,6 @@ protected:
   Box_DB* m_pBox;
 };
 
+} //namespace Glom
+
 #endif
